@@ -16,12 +16,11 @@ from django.views import generic
 
 import openstack_dashboard.urls
 
-urlpatterns = urls.patterns(
-    '',
+urlpatterns = [
     urls.url(
         r'^qunit_tuskar',
         generic.TemplateView.as_view(
             template_name="infrastructure/qunit.html"),
         name='qunit_tests'),
     urls.url(r'', urls.include(openstack_dashboard.urls))
-)
+]
